@@ -2,7 +2,7 @@ use warnings;
 use strict;
 use feature ':5.14';
 
-package Text::Parser 0.916;
+package Text::Parser 0.917;
 
 # ABSTRACT: Simplifies text parsing. Easily extensible to parse any text format.
 
@@ -309,7 +309,7 @@ Text::Parser - Simplifies text parsing. Easily extensible to parse any text form
 
 =head1 VERSION
 
-version 0.916
+version 0.917
 
 =head1 SYNOPSIS
 
@@ -981,10 +981,20 @@ This software is copyright (c) 2018-2019 by Balaji Ramasubramanian.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords H.Merijn Brand - Tux
+=for stopwords H.Merijn Brand - Tux Mohammad S Anwar
+
+=over 4
+
+=item *
 
 H.Merijn Brand - Tux <h.m.brand@xs4all.nl>
 
+=item *
+
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=back
+
 =cut
